import 'dart:io';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

/// This class is used to display dialogs easily without worrying about what
/// platform you use to diplay the dialog. It will automatically adapt to iOS
/// or other platforms
class Dialogs {
  /// This method will display an informative dialog with just one button
  static void infoDialog({
    required BuildContext context,
    required String title,
    required String message,

    /// Button text, default : Ok
    String buttonText = "Ok",

    /// Button text color, default : lightBlue
    Color buttonTextColor = Colors.lightBlue,
    VoidCallback? onPressed,

    /// Not for iOS : default is Color(0xFF424242)
    Color titleTextColor = const Color(0xFF424242),

    /// Not for iOS : default is Color(0xFF424242)
    Color messageTextColor = const Color(0xFF424242),
  }) {
    showDialog(
        context: context,
        builder: (BuildContext context) {
          /// Checking the platform
          if (Platform.isIOS) {
            return CupertinoAlertDialog(
              title: Center(child: Text(title)),
              content: Text(message),
              actions: <Widget>[
                CupertinoDialogAction(
                  isDefaultAction: true,
                  child: Text(
                    buttonText,
                    textAlign: TextAlign.justify,
                    style: TextStyle(color: buttonTextColor),
                  ),
                  onPressed: () {
                    /// If no function, only pop the dialog.
                    Navigator.pop(context);
                    if (onPressed != null) {
                      onPressed();
                    }
                  },
                )
              ],
            );
          } else {
            return AlertDialog(
              title: Center(
                child: Text(
                  title,
                  style: TextStyle(
                      fontSize: 25,
                      fontWeight: FontWeight.bold,
                      color: titleTextColor),
                ),
              ),
              content: Text(
                message,
                style: TextStyle(color: messageTextColor),
              ),
              actions: [
                TextButton(
                  /// usually buttons at the bottom of the dialog
                  child: Text(
                    buttonText,
                    style: TextStyle(fontSize: 20, color: buttonTextColor),
                  ),
                  onPressed: () {
                    Navigator.pop(context);

                    /// If no function, only pop the dialog.
                    if (onPressed != null) {
                      onPressed();
                    }
                  },
                ),
              ],
            );
          }
        });
  }
}
